@@ -6,7 +6,7 @@ use Cwd;
 use base qw(Module::Install::Base);
 use vars qw($VERSION);
 
-$VERSION = '0.04';
+$VERSION = '0.06';
 
 sub githubmeta {
   my $self = shift;
@@ -27,15 +27,19 @@ sub githubmeta {
 sub _under_git {
   my $cwd = getcwd;
   my $last = $cwd;
+  my $found = 0;
   while (1) {
-    chdir '..' or return;
+    chdir '..' or last;
     my $current = getcwd;
-    return if $last eq $current;
+    last if $last eq $current;
     $last = $current;
-    return 1 if -e '.git';
-
+    if ( -e '.git' ) {
+       $found = 1;
+       last;
+    }
   }
-  return;
+  chdir $cwd;
+  return $found;
 }
 
 'Github';
